@@ -237,6 +237,15 @@ class PostbackInfo(BaseModel):
     data: str = Field(max_length=2048)
 
 
+class ReplyActionInfo(BaseModel):
+    """
+    버튼을 눌러서 답장할수있습니다.
+    """
+
+    displayText: str = Field(max_length=200)
+    postback: PostbackInfo
+
+
 class ActionInfo(BaseModel):
     urlAction: Optional[UrlActionInfo]
     localBrowserAction: Optional[LocalBrowserActionInfo]
@@ -250,7 +259,8 @@ class ActionInfo(BaseModel):
 
 
 class SuggestionInfo(BaseModel):
-    action: ActionInfo
+    action: Optional[ActionInfo]
+    reply: Optional[ReplyActionInfo]
 
 
 class ButtonInfo(BaseModel):
@@ -379,9 +389,9 @@ class RcsInfo(BaseModel):
     버튼의 변수부를 등록 하여 사용하며, 해당 필드 허용하지 않음.
     """
 
-    chipLists: Optional[List]
+    chipList: Optional[List]
     """
-    # chipLists
+    # chipList
     GSMA RCC.07의3.6.10.4의 ‘suggestion’ 규격에 따라 chiplist를 구성(RCC.07의 기준 버전 확인 필요)
     ㅇRCSCHAT인 경우에만 사용.
     * Chiplist는 최대 11개까지 사용 가능하다
@@ -453,7 +463,7 @@ class StatusInfo(BaseModel):
     legacyError: Optional[LegacyErrorCodeEnum]
     timestamp: str = Field(regex=r"^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d{3}\+\d{2}$")
     autoReplyMsgId: Optional[str] = Field(max_length=40)
-    postBackId: Optional[str] = Field(max_length=40)
+    postbackId: Optional[str] = Field(max_length=40)
     chatbotId: Optional[str] = Field(max_length=40)
     bill: Optional[enums.BillEnum]
 
@@ -494,11 +504,11 @@ class FileMessageInfo(BaseModel):
 
 
 class GeolocationPushMessage(BaseModel):
-    label: str
-    timestamp: str
-    timeOffset: str
-    pos: str
-    radius: int
+    label: Optional[str]
+    timestamp: Optional[str]
+    timeOffset: Optional[str]
+    pos: Optional[str]
+    radius: Optional[int]
 
 
 class UserLocationInfo(BaseModel):
@@ -519,8 +529,8 @@ class MessageInfo(BaseModel):
     고객이 단말 대화방을 최초 진입 시 설정됨
     Maximum : 10Byte
     """
-    postBackId: Optional[str] = Field(max_length=40)
-    postBackData: Optional[str] = Field(max_length=2048)
+    postbackId: Optional[str] = Field(max_length=40)
+    postbackData: Optional[str] = Field(max_length=2048)
     displayText: Optional[str] = Field(max_length=200)
     messageBody: Union[TextMessageInfo, UserLocationInfo, FileMessageInfo, None]
     """
